@@ -71,9 +71,10 @@ def uORF(args):
         if t.strand == '-':
             cdna = cdna.reverse_complement()
         #print(pt)
-        print(mt)
-        print(cdna)
-        uORF_dict = uorf(t.id, mt, cdna)
+        #print(mt)
+        #print(cdna)
+        #uORF_dict = uorf(t.id, mt, cdna)
+        uORF_dict = uorf(t.id, t.chrom, t.strand, mt, cdna)
         print(t.id)
         for key in uORF_dict:
             print(key,len(uORF_dict[key]))
@@ -82,8 +83,8 @@ def uORF(args):
         print(uORF_dict)
         index += 1
         #if index == 8:
-        if index == 2:
-            break
+        #if index == 2:
+        #    break
         
         
 uORF('ath.fa')
